@@ -3,7 +3,7 @@ use readpassphrase::{clear_passphrase, readpassphrase, Flags};
 // Test program to ensure readpassphrase is working correctly
 fn main() {
     let prompt = "Enter passphrase: ";
-    let mut passphrase = readpassphrase(prompt, 1024, Flags::RequireTty).expect("failed to read passphrase from /dev/tty");
+    let mut passphrase = readpassphrase(prompt, 1024, Flags::RequireTty.into()).expect("failed to read passphrase from /dev/tty");
     println!("You entered: {}", passphrase);
 
     // clear the passphrase
